@@ -34,7 +34,7 @@ import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommand
 import org.kie.workbench.common.dmn.client.editors.expressions.types.BaseEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.hitpolicy.HitPolicyPopoverView;
-import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
@@ -42,11 +42,11 @@ import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
@@ -55,7 +55,7 @@ import org.uberfire.ext.wires.core.grids.client.model.GridData;
 public class DecisionTableEditorDefinition extends BaseEditorDefinition<DecisionTable, DecisionTableGridData> {
 
     private HitPolicyPopoverView.Presenter hitPolicyEditor;
-    private ManagedInstance<NameAndDataTypePopoverView.Presenter> headerEditors;
+    private ManagedInstance<ValueAndDataTypePopoverView.Presenter> headerEditors;
     private DecisionTableEditorDefinitionEnricher enricher;
 
     public DecisionTableEditorDefinition() {
@@ -65,7 +65,7 @@ public class DecisionTableEditorDefinition extends BaseEditorDefinition<Decision
     @Inject
     public DecisionTableEditorDefinition(final DefinitionUtils definitionUtils,
                                          final SessionManager sessionManager,
-                                         final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                         final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                                          final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
                                          final Event<ExpressionEditorChanged> editorSelectedEvent,
                                          final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
@@ -73,8 +73,9 @@ public class DecisionTableEditorDefinition extends BaseEditorDefinition<Decision
                                          final ListSelectorView.Presenter listSelector,
                                          final TranslationService translationService,
                                          final HitPolicyPopoverView.Presenter hitPolicyEditor,
-                                         final ManagedInstance<NameAndDataTypePopoverView.Presenter> headerEditors,
-                                         final DecisionTableEditorDefinitionEnricher enricher) {
+                                         final ManagedInstance<ValueAndDataTypePopoverView.Presenter> headerEditors,
+                                         final DecisionTableEditorDefinitionEnricher enricher,
+                                         final ReadOnlyProvider readOnlyProvider) {
         super(definitionUtils,
               sessionManager,
               sessionCommandManager,
@@ -83,7 +84,8 @@ public class DecisionTableEditorDefinition extends BaseEditorDefinition<Decision
               refreshFormPropertiesEvent,
               domainObjectSelectionEvent,
               listSelector,
-              translationService);
+              translationService,
+              readOnlyProvider);
         this.hitPolicyEditor = hitPolicyEditor;
         this.headerEditors = headerEditors;
         this.enricher = enricher;
@@ -139,7 +141,8 @@ public class DecisionTableEditorDefinition extends BaseEditorDefinition<Decision
                                                  isOnlyVisualChangeAllowed,
                                                  nesting,
                                                  hitPolicyEditor,
-                                                 headerEditors));
+                                                 headerEditors,
+                                                 readOnlyProvider));
     }
 
     @Override
