@@ -17,6 +17,7 @@
 package org.kie.workbench.common.dmn.client.editors.search;
 
 import java.util.List;
+import java.util.Objects;
 import java.util.Optional;
 import java.util.function.Supplier;
 
@@ -25,9 +26,9 @@ import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
-import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditor;
 import org.kie.workbench.common.dmn.client.session.DMNSession;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.widgets.client.search.common.BaseEditorSearchIndex;
 import org.kie.workbench.common.widgets.client.search.common.SearchPerformedEvent;
 import org.uberfire.mvp.Command;
@@ -126,18 +127,24 @@ public class DMNEditorSearchIndex extends BaseEditorSearchIndex<DMNSearchableEle
         if (getIsDataTypesTabActiveSupplier().get()) {
             return DATA_TYPES;
         }
-        if (getExpressionEditor().isActive()) {
+        if (isExpressionEditorActive()) {
             return BOXED_EXPRESSION;
         }
         return GRAPH;
     }
 
-    private ExpressionEditor getExpressionEditor() {
-        return (ExpressionEditor) getCurrentSession().getExpressionEditor();
+    private boolean isExpressionEditorActive() {
+        final DMNSession session = getCurrentDMNSession();
+        if (Objects.isNull(session)) {
+            return false;
+        }
+        return session.getExpressionEditor().isActive();
     }
 
-    private DMNSession getCurrentSession() {
-        return sessionManager.getCurrentSession();
+    @SuppressWarnings("all")
+    private DMNSession getCurrentDMNSession() {
+        ClientSession s = sessionManager.getCurrentSession();
+        return s instanceof DMNSession ? (DMNSession) s : null;
     }
 
     enum SearchContext {
