@@ -19,10 +19,10 @@ package org.kie.workbench.common.dmn.client.editors.expressions.types.undefined;
 import java.util.Collections;
 import java.util.List;
 import java.util.Optional;
+import java.util.function.Function;
 import java.util.function.Supplier;
 
 import com.ait.lienzo.client.core.event.NodeMouseClickEvent;
-import com.ait.lienzo.client.core.event.NodeMouseClickHandler;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
@@ -30,15 +30,18 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.NOPDomainObject;
+import org.kie.workbench.common.dmn.api.definition.model.Decision;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.undefined.SetCellValueCommand;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextGrid;
-import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.literal.LiteralExpressionCell;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.selector.UndefinedExpressionSelectorPopoverView;
 import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
@@ -48,24 +51,35 @@ import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSel
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl.ListSelectorDividerItem;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl.ListSelectorTextItem;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.handlers.DelegatingGridWidgetCellSelectorMouseEventHandler;
+import org.kie.workbench.common.dmn.client.widgets.grid.handlers.DelegatingGridWidgetEditCellMouseEventHandler;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.session.impl.ManagedSession;
+import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.graph.Graph;
+import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
-import org.uberfire.ext.wires.core.grids.client.model.GridCell;
+import org.mockito.Mockito;
+import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCell;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.NodeMouseEventHandler;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
 import org.uberfire.mocks.EventSourceMock;
@@ -73,11 +87,11 @@ import org.uberfire.mvp.Command;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.doCallRealMethod;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -91,6 +105,10 @@ public class UndefinedExpressionGridTest {
 
     private static final String NODE_UUID = "uuid";
 
+    private static final int PARENT_ROW_INDEX = 0;
+
+    private static final int PARENT_COLUMN_INDEX = 1;
+
     @Mock
     private DMNGridPanel gridPanel;
 
@@ -107,13 +125,22 @@ public class UndefinedExpressionGridTest {
     private DMNEditorSession session;
 
     @Mock
-    private AbstractCanvasHandler handler;
+    private AbstractCanvasHandler canvasHandler;
+
+    @Mock
+    private Diagram diagram;
+
+    @Mock
+    private Graph graph;
+
+    @Mock
+    private Node node;
 
     @Mock
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
     @Mock
-    private CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
+    private DefaultCanvasCommandFactory canvasCommandFactory;
 
     @Mock
     private CellEditorControlsView.Presenter cellEditorControls;
@@ -124,6 +151,9 @@ public class UndefinedExpressionGridTest {
     @Mock
     private TranslationService translationService;
 
+    @Mock
+    private UndefinedExpressionSelectorPopoverView.Presenter undefinedExpressionSelector;
+
     @Mock
     private Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
 
@@ -154,15 +184,30 @@ public class UndefinedExpressionGridTest {
     @Mock
     private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
 
+    @Mock
+    private EventSourceMock<RefreshFormPropertiesEvent> refreshFormPropertiesEvent;
+
+    @Mock
+    private EventSourceMock<DomainObjectSelectionEvent> domainObjectSelectionEvent;
+
     @Mock
     private ManagedSession managedSession;
 
+    @Mock
+    private ReadOnlyProvider readOnlyProvider;
+
     @Captor
     private ArgumentCaptor<SetCellValueCommand> setCellValueCommandArgumentCaptor;
 
+    @Captor
+    private ArgumentCaptor<RefreshFormPropertiesEvent> refreshFormPropertiesArgumentCaptor;
+
     @Captor
     private ArgumentCaptor<GridLayerRedrawManager.PrioritizedCommand> redrawCommandArgumentCaptor;
 
+    @Captor
+    private ArgumentCaptor<DomainObjectSelectionEvent> domainObjectSelectionArgumentEventCaptor;
+
     private LiteralExpression literalExpression = new LiteralExpression();
 
     private Optional<Expression> expression = Optional.empty();
@@ -178,21 +223,27 @@ public class UndefinedExpressionGridTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() {
+        when(sessionManager.getCurrentSession()).thenReturn(session);
+        when(session.getGridPanel()).thenReturn(gridPanel);
+        when(session.getGridLayer()).thenReturn(gridLayer);
+        when(session.getCellEditorControls()).thenReturn(cellEditorControls);
+
         expressionGridCache = spy(new ExpressionGridCacheImpl());
         when(sessionManager.getCurrentSession()).thenReturn(session);
         when(session.getExpressionGridCache()).thenReturn(expressionGridCache);
 
-        definition = new UndefinedExpressionEditorDefinition(gridPanel,
-                                                             gridLayer,
-                                                             definitionUtils,
+        definition = new UndefinedExpressionEditorDefinition(definitionUtils,
                                                              sessionManager,
                                                              sessionCommandManager,
                                                              canvasCommandFactory,
                                                              editorSelectedEvent,
-                                                             cellEditorControls,
+                                                             refreshFormPropertiesEvent,
+                                                             domainObjectSelectionEvent,
                                                              listSelector,
                                                              translationService,
-                                                             expressionEditorDefinitionsSupplier);
+                                                             undefinedExpressionSelector,
+                                                             expressionEditorDefinitionsSupplier,
+                                                             readOnlyProvider);
 
         expression = definition.getModelClass();
 
@@ -200,54 +251,106 @@ public class UndefinedExpressionGridTest {
         expressionEditorDefinitions.add(definition);
         expressionEditorDefinitions.add(literalExpressionEditorDefinition);
 
-        doReturn(expressionEditorDefinitions).when(expressionEditorDefinitionsSupplier).get();
-        doReturn(ExpressionType.LITERAL_EXPRESSION).when(literalExpressionEditorDefinition).getType();
-        doReturn(LiteralExpression.class.getSimpleName()).when(literalExpressionEditorDefinition).getName();
-        doReturn(Optional.of(literalExpression)).when(literalExpressionEditorDefinition).getModelClass();
-        doReturn(Optional.of(literalExpressionEditor)).when(literalExpressionEditorDefinition).getEditor(any(GridCellTuple.class),
-                                                                                                         any(Optional.class),
-                                                                                                         any(HasExpression.class),
-                                                                                                         any(Optional.class),
-                                                                                                         any(Optional.class),
-                                                                                                         anyInt());
+        when(expressionEditorDefinitionsSupplier.get()).thenReturn(expressionEditorDefinitions);
+        when(literalExpressionEditorDefinition.getType()).thenReturn(ExpressionType.LITERAL_EXPRESSION);
+        when(literalExpressionEditorDefinition.getName()).thenReturn(LiteralExpression.class.getSimpleName());
+        doCallRealMethod().when(literalExpressionEditor).selectFirstCell();
+        when(literalExpressionEditor.getLayer()).thenReturn(gridLayer);
 
-        doReturn(session).when(sessionManager).getCurrentSession();
-        doReturn(handler).when(session).getCanvasHandler();
+        final GridData literalExpressionUiModel = new BaseGridData();
+        literalExpressionUiModel.appendColumn(mock(GridColumn.class));
+        literalExpressionUiModel.appendRow(mock(GridRow.class));
+        when(literalExpressionEditor.getModel()).thenReturn(literalExpressionUiModel);
+
+        when(literalExpressionEditorDefinition.getModelClass()).thenReturn(Optional.of(literalExpression));
+        when(literalExpressionEditorDefinition.getEditor(any(GridCellTuple.class),
+                                                         any(Optional.class),
+                                                         any(HasExpression.class),
+                                                         any(Optional.class),
+                                                         anyBoolean(),
+                                                         anyInt())).thenReturn(Optional.of(literalExpressionEditor));
+
+        when(session.getCanvasHandler()).thenReturn(canvasHandler);
+        when(canvasHandler.getDiagram()).thenReturn(diagram);
+        when(diagram.getGraph()).thenReturn(graph);
+        when(graph.nodes()).thenReturn(Collections.singletonList(node));
 
         when(parentGridWidget.getModel()).thenReturn(parentGridUiModel);
+        setupParent();
+    }
+
+    private void setupParent() {
         when(parent.getGridWidget()).thenReturn(parentGridWidget);
-        when(parent.getRowIndex()).thenReturn(0);
-        when(parent.getColumnIndex()).thenReturn(1);
+        when(parent.getRowIndex()).thenReturn(PARENT_ROW_INDEX);
+        when(parent.getColumnIndex()).thenReturn(PARENT_COLUMN_INDEX);
     }
 
     private void setupGrid(final int nesting) {
         this.grid = spy((UndefinedExpressionGrid) definition.getEditor(parent,
                                                                        nesting == 0 ? Optional.of(NODE_UUID) : Optional.empty(),
                                                                        hasExpression,
-                                                                       expression,
                                                                        hasName,
+                                                                       false,
                                                                        nesting).get());
     }
 
     @Test
-    public void testGridMouseClickHandler() {
+    public void testMouseClickEventHandlers() {
         setupGrid(0);
 
-        final NodeMouseClickHandler handler = grid.getGridMouseClickHandler(selectionManager);
-
-        handler.onNodeMouseClick(mouseClickEvent);
-
-        verify(gridLayer).select(parentGridWidget);
+        final List<NodeMouseEventHandler> handlers = grid.getNodeMouseClickEventHandlers(selectionManager);
+        assertThat(handlers).hasSize(2);
+        assertThat(handlers.get(0)).isInstanceOf(DelegatingGridWidgetCellSelectorMouseEventHandler.class);
+        assertThat(handlers.get(1)).isInstanceOf(DelegatingGridWidgetEditCellMouseEventHandler.class);
     }
 
     @Test
-    public void testSelectFirstCell() {
+    public void testMouseDoubleClickEventHandlers() {
         setupGrid(0);
 
+        final List<NodeMouseEventHandler> handlers = grid.getNodeMouseDoubleClickEventHandlers(selectionManager, gridLayer);
+        assertThat(handlers).isEmpty();
+    }
+
+    @Test
+    public void testSelectFirstCellWhenNested() {
+        setupGrid(1);
+
+        final Decision decision = mock(Decision.class);
+        when(hasExpression.asDMNModelInstrumentedBase()).thenReturn(decision);
+
         grid.selectFirstCell();
 
-        verify(parentGridUiModel).clearSelections();
-        verify(parentGridUiModel).selectCell(eq(0), eq(1));
+        assertThat(grid.getModel().getSelectedCells().size()).isEqualTo(0);
+        verify(parentGridUiModel).selectCell(eq(PARENT_ROW_INDEX), eq(PARENT_COLUMN_INDEX));
+        verify(gridLayer).select(parentGridWidget);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionArgumentEventCaptor.capture());
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionArgumentEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getCanvasHandler()).isEqualTo(canvasHandler);
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isInstanceOf(NOPDomainObject.class);
+    }
+
+    @Test
+    public void testSelectFirstCellWhenNotNested() {
+        setupGrid(0);
+
+        final Decision decision = mock(Decision.class);
+        when(hasExpression.asDMNModelInstrumentedBase()).thenReturn(decision);
+
+        grid.selectFirstCell();
+
+        final List<GridData.SelectedCell> selectedCells = grid.getModel().getSelectedCells();
+        assertThat(selectedCells.size()).isEqualTo(1);
+        assertThat(selectedCells.get(0).getRowIndex()).isEqualTo(0);
+        assertThat(selectedCells.get(0).getColumnIndex()).isEqualTo(0);
+
+        verify(gridLayer).select(grid);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionArgumentEventCaptor.capture());
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionArgumentEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getCanvasHandler()).isEqualTo(canvasHandler);
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isEqualTo(decision);
     }
 
     @Test
@@ -255,17 +358,9 @@ public class UndefinedExpressionGridTest {
     public void testResizeBasedOnCellExpressionEditor() {
         setupGrid(0);
 
-        final GridCell parentCell = mock(GridCell.class);
-        final ExpressionCellValue parentValue = mock(ExpressionCellValue.class);
-        final BaseExpressionGrid parentGrid = mock(BaseExpressionGrid.class);
+        grid.resize(BaseExpressionGrid.RESIZE_EXISTING);
 
-        when(parentGridUiModel.getCell(0, 1)).thenReturn(parentCell);
-        when(parentCell.getValue()).thenReturn(parentValue);
-        when(parentValue.getValue()).thenReturn(Optional.of(parentGrid));
-
-        grid.resizeBasedOnCellExpressionEditor(0, 1);
-
-        verify(parentGrid).resizeWhenExpressionEditorChanged();
+        assertResize(BaseExpressionGrid.RESIZE_EXISTING);
     }
 
     @Test
@@ -285,20 +380,6 @@ public class UndefinedExpressionGridTest {
         assertThat(uiModel.getCell(0, 0)).isInstanceOf(UndefinedExpressionCell.class);
     }
 
-    @Test
-    public void testHeaderVisibilityWhenNested() {
-        setupGrid(1);
-
-        assertTrue(grid.isHeaderHidden());
-    }
-
-    @Test
-    public void testHeaderVisibilityWhenNotNested() {
-        setupGrid(0);
-
-        assertTrue(grid.isHeaderHidden());
-    }
-
     @Test
     public void testCacheable() {
         setupGrid(0);
@@ -436,43 +517,79 @@ public class UndefinedExpressionGridTest {
     public void testOnExpressionTypeChangedWhenNested() {
         assertOnExpressionTypeChanged(1);
 
-        verify(expressionGridCache, never()).getExpressionGrid(anyString());
+        verify(expressionGridCache, never()).getExpressionGrid(Mockito.<String>any());
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionArgumentEventCaptor.capture());
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionArgumentEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isInstanceOf(NOPDomainObject.class);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testOnExpressionTypeChangedWhenNotNested() {
+        final Decision decision = mock(Decision.class);
+        when(hasExpression.asDMNModelInstrumentedBase()).thenReturn(decision);
+
         assertOnExpressionTypeChanged(0);
 
         verify(expressionGridCache).getExpressionGrid(eq(NODE_UUID));
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionArgumentEventCaptor.capture());
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionArgumentEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getCanvasHandler()).isEqualTo(canvasHandler);
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isEqualTo(decision);
+    }
+
+    private void assertResize(final Function<BaseExpressionGrid, Double> expectedResizer) {
+        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth()), eq(expectedResizer));
+        verify(gridPanel).refreshScrollPosition();
+        verify(gridPanel).updatePanelSize();
+        verify(parent).onResize();
+
+        verify(gridLayer).batch(redrawCommandArgumentCaptor.capture());
+
+        redrawCommandArgumentCaptor.getValue().execute();
+
+        verify(gridLayer).draw();
     }
 
     @SuppressWarnings("unchecked")
     private void assertOnExpressionTypeChanged(final int nesting) {
         setupGrid(nesting);
 
-        final GridCell parentCell = mock(GridCell.class);
-        final ExpressionCellValue parentCellValue = mock(ExpressionCellValue.class);
-        final BaseExpressionGrid parentGridEditor = mock(BaseExpressionGrid.class);
-        when(parentGridUiModel.getCell(anyInt(), anyInt())).thenReturn(parentCell);
-        when(parentCell.getValue()).thenReturn(parentCellValue);
-        when(parentCellValue.getValue()).thenReturn(Optional.of(parentGridEditor));
-
         grid.onExpressionTypeChanged(ExpressionType.LITERAL_EXPRESSION);
 
+        verify(sessionCommandManager).execute(eq(canvasHandler),
+                                              setCellValueCommandArgumentCaptor.capture());
+
+        final SetCellValueCommand setCellValueCommand = setCellValueCommandArgumentCaptor.getValue();
+        setCellValueCommand.execute(canvasHandler);
+
         verify(literalExpressionEditorDefinition).getEditor(eq(parent),
                                                             eq(nesting == 0 ? Optional.of(NODE_UUID) : Optional.empty()),
                                                             eq(hasExpression),
-                                                            eq(Optional.of(literalExpression)),
                                                             eq(hasName),
+                                                            eq(false),
                                                             eq(nesting));
 
-        verify(sessionCommandManager).execute(eq(handler),
-                                              setCellValueCommandArgumentCaptor.capture());
+        assertResize(BaseExpressionGrid.RESIZE_EXISTING);
+        verify(literalExpressionEditor).selectCell(eq(0),
+                                                   eq(0),
+                                                   eq(false),
+                                                   eq(false));
+        verify(literalExpressionEditor).selectFirstCell();
+        verify(gridPanel).setFocus(true);
 
-        final SetCellValueCommand setCellValueCommand = setCellValueCommandArgumentCaptor.getValue();
-        setCellValueCommand.execute(handler);
+        reset(gridPanel, gridLayer, parent);
+        setupParent();
 
-        verify(parentGridEditor).resizeWhenExpressionEditorChanged();
+        setCellValueCommand.undo(canvasHandler);
+
+        assertResize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+        verify(gridLayer).select(grid);
+        verify(grid).selectCell(eq(0),
+                                eq(0),
+                                eq(false),
+                                eq(false));
     }
 }
