@@ -20,11 +20,12 @@ import java.util.List;
 import java.util.Optional;
 import java.util.function.Supplier;
 
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpressionPMMLDocument;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpressionPMMLDocument;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
@@ -32,16 +33,17 @@ import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.U
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.Mockito;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class UndefinedExpressionSelectorPopoverImplTest {
 
     @Mock
@@ -62,11 +64,12 @@ public class UndefinedExpressionSelectorPopoverImplTest {
     @Mock
     private UndefinedExpressionGrid undefinedExpressionGrid;
 
+    @Mock
+    private TranslationService translationService;
+
     @Captor
     private ArgumentCaptor<List<ExpressionEditorDefinition>> expressionDefinitionsCaptor;
 
-    private Optional<String> title = Optional.of("title");
-
     private LiteralExpression literalExpression = new LiteralExpression();
 
     private LiteralExpressionPMMLDocument literalExpressionPMMLDocument = new LiteralExpressionPMMLDocument();
@@ -95,7 +98,9 @@ public class UndefinedExpressionSelectorPopoverImplTest {
 
         when(expressionEditorDefinitionsSupplier.get()).thenReturn(expressionEditorDefinitions);
 
-        this.popover = new UndefinedExpressionSelectorPopoverImpl(view, expressionEditorDefinitionsSupplier);
+        when(translationService.getTranslation(Mockito.<String>any())).thenAnswer(i -> i.getArguments()[0]);
+
+        this.popover = new UndefinedExpressionSelectorPopoverImpl(view, translationService, expressionEditorDefinitionsSupplier);
     }
 
     @Test
@@ -112,15 +117,15 @@ public class UndefinedExpressionSelectorPopoverImplTest {
     public void testShowWhenBound() {
         popover.bind(undefinedExpressionGrid, 0, 0);
 
-        popover.show(title);
+        popover.show();
 
-        verify(view).show(eq(title));
+        verify(view).show(eq(Optional.ofNullable(popover.getPopoverTitle())));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testShowWhenNotBound() {
-        popover.show(title);
+        popover.show();
 
         verify(view, never()).show(any(Optional.class));
     }
