@@ -18,6 +18,7 @@ package org.kie.workbench.common.screens.examples.backend.server;
 
 import java.io.File;
 import java.net.URL;
+import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -31,6 +32,7 @@ import java.util.Set;
 import javax.enterprise.event.Event;
 
 import org.apache.commons.io.FileUtils;
+import org.guvnor.common.services.project.backend.server.utils.PathUtil;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.common.services.project.events.NewProjectEvent;
 import org.guvnor.common.services.project.model.Module;
@@ -46,7 +48,7 @@ import org.guvnor.structure.organizationalunit.config.SpaceConfigStorage;
 import org.guvnor.structure.organizationalunit.config.SpaceConfigStorageRegistry;
 import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
 import org.guvnor.structure.repositories.Branch;
-import org.guvnor.structure.repositories.RepositoryCopier;
+import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.repositories.impl.git.GitRepository;
 import org.guvnor.structure.server.repositories.RepositoryFactory;
 import org.jboss.errai.security.shared.api.identity.User;
@@ -65,8 +67,9 @@ import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.mockito.Spy;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
@@ -77,13 +80,13 @@ import org.uberfire.rpc.SessionInfo;
 import org.uberfire.spaces.Space;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.screens.examples.backend.server.ImportUtils.makeGitRepository;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -93,7 +96,7 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ExamplesServiceImplTest {
 
     @Mock
@@ -105,9 +108,6 @@ public class ExamplesServiceImplTest {
     @Mock
     private KieModuleService moduleService;
 
-    @Mock
-    private RepositoryCopier repositoryCopier;
-
     @Mock
     private OrganizationalUnitService ouService;
 
@@ -159,12 +159,17 @@ public class ExamplesServiceImplTest {
     @Mock
     private FileSystem systemFS;
 
+    private PathUtil pathUtil = new PathUtil();
+
+    @Mock
+    private RepositoryService repositoryService;
+
     @Before
     public void setup() throws Exception {
 
-        when(spaceConfigStorageRegistry.get(anyString())).thenReturn(spaceConfigStorage);
-        when(spaceConfigStorageRegistry.getBatch(anyString())).thenReturn(new SpaceConfigStorageRegistryImpl.SpaceStorageBatchImpl(spaceConfigStorage));
-        when(spaceConfigStorageRegistry.exist(anyString())).thenReturn(true);
+        when(spaceConfigStorageRegistry.get(Mockito.<String>any())).thenReturn(spaceConfigStorage);
+        when(spaceConfigStorageRegistry.getBatch(Mockito.<String>any())).thenReturn(new SpaceConfigStorageRegistryImpl.SpaceStorageBatchImpl(spaceConfigStorage));
+        when(spaceConfigStorageRegistry.exist(Mockito.<String>any())).thenReturn(true);
 
         when(ou.getSpace()).thenReturn(space);
         when(space.getName()).thenReturn("ou");
@@ -172,7 +177,6 @@ public class ExamplesServiceImplTest {
         service = spy(new ExamplesServiceImpl(ioService,
                                               repositoryFactory,
                                               moduleService,
-                                              repositoryCopier,
                                               ouService,
                                               projectService,
                                               metadataService,
@@ -180,7 +184,9 @@ public class ExamplesServiceImplTest {
                                               projectScreenService,
                                               validators,
                                               spaceConfigStorageRegistry,
-                                              systemFS));
+                                              systemFS,
+                                              pathUtil,
+                                              repositoryService));
 
         FileUtils.deleteDirectory(new File(".kie-wb-playground"));
 
@@ -192,10 +198,10 @@ public class ExamplesServiceImplTest {
             OrganizationalUnitImpl o = new OrganizationalUnitImpl(spaceName, defaultGroupId);
             organizationalUnits.put(spaceName, o);
             return o;
-        }).when(ouService).createOrganizationalUnit(anyString(), anyString());
+        }).when(ouService).createOrganizationalUnit(Mockito.<String>any(), Mockito.<String>any());
 
         doAnswer(invocationOnMock -> organizationalUnits.get(invocationOnMock.getArguments()[0]))
-                .when(ouService).getOrganizationalUnit(anyString());
+                .when(ouService).getOrganizationalUnit(Mockito.<String>any());
 
         when(ouService.getOrganizationalUnits()).thenReturn(new HashSet<OrganizationalUnit>() {{
             add(new OrganizationalUnitImpl("ou1Name",
@@ -203,7 +209,7 @@ public class ExamplesServiceImplTest {
             add(new OrganizationalUnitImpl("ou2Name",
                                            "ou2GroupId"));
         }});
-        when(moduleService.resolveModule(any(Path.class))).thenAnswer((Answer<KieModule>) invocationOnMock -> {
+        when(moduleService.resolveModule(Mockito.<Path>any())).thenAnswer((Answer<KieModule>) invocationOnMock -> {
             final Path path = (Path) invocationOnMock.getArguments()[0];
             final KieModule module = new KieModule(path,
                                                    path,
@@ -259,7 +265,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_NullRepository() {
-        final Set<ImportProject> modules = service.getProjects(null);
+        final Set<ImportProject> modules = service.getProjects(ou, null);
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -267,7 +273,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_NullRepositoryUrl() {
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(null));
+        final Set<ImportProject> modules = service.getProjects(ou, new ExampleRepository(null));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -275,7 +281,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_EmptyRepositoryUrl() {
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(""));
+        final Set<ImportProject> modules = service.getProjects(ou, new ExampleRepository(""));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -283,7 +289,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_WhiteSpaceRepositoryUrl() {
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository("   "));
+        final Set<ImportProject> modules = service.getProjects(ou, new ExampleRepository("   "));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -296,19 +302,19 @@ public class ExamplesServiceImplTest {
         when(module.getRootPath()).thenReturn(moduleRoot);
         when(module.getModuleName()).thenReturn("module1");
         when(moduleRoot.toURI()).thenReturn("default:///module1");
-        when(metadataService.getTags(any(Path.class))).thenReturn(Arrays.asList("tag1",
-                                                                                "tag2"));
+        when(metadataService.getTags(Mockito.<Path>any())).thenReturn(Arrays.asList("tag1",
+                                                                                    "tag2"));
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
-        when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
+        when(repositoryFactory.newRepository(Mockito.<RepositoryInfo>any())).thenReturn(repository);
+        when(moduleService.getAllModules(Mockito.<Branch>any())).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
 
         service.setPlaygroundRepository(mock(ExampleRepository.class));
 
         String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
+        final Set<ImportProject> modules = service.getProjects(ou, new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
@@ -330,19 +336,19 @@ public class ExamplesServiceImplTest {
         when(module.getRootPath()).thenReturn(moduleRoot);
         when(module.getModuleName()).thenReturn("module1");
         when(moduleRoot.toURI()).thenReturn("default:///module1");
-        when(ioService.exists(any(org.uberfire.java.nio.file.Path.class))).thenReturn(true);
-        when(ioService.readAllString(any(org.uberfire.java.nio.file.Path.class))).thenReturn("This is custom description.\n\n This is a new line.");
-        when(metadataService.getTags(any(Path.class))).thenReturn(Arrays.asList("tag1",
-                                                                                "tag2"));
+        when(ioService.exists(Mockito.<org.uberfire.java.nio.file.Path>any())).thenReturn(true);
+        when(ioService.readAllString(Mockito.<org.uberfire.java.nio.file.Path>any())).thenReturn("This is custom description.\n\n This is a new line.");
+        when(metadataService.getTags(Mockito.<Path>any())).thenReturn(Arrays.asList("tag1",
+                                                                                    "tag2"));
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
-        when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
+        when(repositoryFactory.newRepository(Mockito.<RepositoryInfo>any())).thenReturn(repository);
+        when(moduleService.getAllModules(Mockito.<Branch>any())).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
 
         String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
+        final Set<ImportProject> modules = service.getProjects(ou, new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
@@ -367,17 +373,17 @@ public class ExamplesServiceImplTest {
         when(module.getModuleName()).thenReturn("module1");
         when(module.getPom()).thenReturn(pom);
         when(moduleRoot.toURI()).thenReturn("default:///module1");
-        when(metadataService.getTags(any(Path.class))).thenReturn(Arrays.asList("tag1",
-                                                                                "tag2"));
+        when(metadataService.getTags(Mockito.<Path>any())).thenReturn(Arrays.asList("tag1",
+                                                                                    "tag2"));
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
-        when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
+        when(repositoryFactory.newRepository(Mockito.<RepositoryInfo>any())).thenReturn(repository);
+        when(moduleService.getAllModules(Mockito.<Branch>any())).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
 
         String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
+        final Set<ImportProject> modules = service.getProjects(ou, new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
@@ -424,7 +430,7 @@ public class ExamplesServiceImplTest {
         when(exModule.getName()).thenReturn("module");
         when(exModule.getRoot()).thenReturn(moduleRoot);
 
-        when(repository.getDefaultBranch()).thenReturn(Optional.of(new Branch("master",
+        when(repository.getDefaultBranch()).thenReturn(Optional.of(new Branch("main",
                                                                               repositoryRoot)));
         when(repositoryRoot.toURI()).thenReturn("default:///");
         when(moduleRoot.toURI()).thenReturn("default:///module");
@@ -432,10 +438,11 @@ public class ExamplesServiceImplTest {
         when(ouService.getOrganizationalUnit(eq("ou"))).thenReturn(null);
         when(ouService.createOrganizationalUnit(eq("ou"),
                                                 eq(""))).thenReturn(ou);
-        when(repositoryCopier.copy(eq(ou),
-                                   anyString(),
-                                   eq(moduleRoot))).thenReturn(repository);
         final WorkspaceProject project = spy(new WorkspaceProject());
+
+        doReturn(project).when(service).importProject(eq(ou),
+                                                      eq(exModule));
+
         doReturn("project").when(project).getName();
         doReturn(project).when(projectService).resolveProject(repository);
 
@@ -449,12 +456,11 @@ public class ExamplesServiceImplTest {
         verify(ouService,
                times(1)).createOrganizationalUnit(eq("ou"),
                                                   eq(""));
-        verify(repositoryCopier,
-               times(1)).copy(eq(ou),
-                              anyString(),
-                              eq(moduleRoot));
+        verify(service,
+               times(1)).importProject(eq(ou),
+                                       eq(exModule));
         verify(newProjectEvent,
-               times(1)).fire(any(NewProjectEvent.class));
+               times(1)).fire(Mockito.<NewProjectEvent>any());
     }
 
     @Test
@@ -480,10 +486,10 @@ public class ExamplesServiceImplTest {
 
         when(repository1.getBranch("dev_branch")).thenReturn(Optional.of(new Branch("dev_branch",
                                                                                     repositoryRoot)));
-        final Optional<Branch> master = Optional.of(new Branch("master",
+        final Optional<Branch> main = Optional.of(new Branch("main",
                                                                PathFactory.newPath("testFile",
                                                                                    "file:///")));
-        when(repository1.getDefaultBranch()).thenReturn(master);
+        when(repository1.getDefaultBranch()).thenReturn(main);
 
         when(repositoryRoot.toURI()).thenReturn("default:///");
         when(module1Root.toURI()).thenReturn("default:///module1");
@@ -491,34 +497,32 @@ public class ExamplesServiceImplTest {
 
         when(ouService.getOrganizationalUnit(eq("ou"))).thenReturn(ou);
 
-        doReturn(repository1).when(repositoryCopier).copy(eq(ou),
-                                                          anyString(),
-                                                          eq(module1Root));
-
-        doReturn(repository1).when(repositoryCopier).copy(eq(ou),
-                                                          anyString(),
-                                                          eq(module2Root));
         final WorkspaceProject project = spy(new WorkspaceProject());
+
+        doReturn(project).when(service).importProject(eq(ou),
+                                                      eq(exProject1));
+
+        doReturn(project).when(service).importProject(eq(ou),
+                                                      eq(exProject2));
         doReturn("project").when(project).getName();
         doReturn(project).when(projectService).resolveProject(repository1);
 
         final WorkspaceProjectContextChangeEvent event = service.setupExamples(exOU,
                                                                                exProjects);
 
-        assertNull(event.getOrganizationalUnit());
-        assertEquals(project,
-                     event.getWorkspaceProject());
+        assertNull(event.getWorkspaceProject());
+        assertEquals(ou,
+                     event.getOrganizationalUnit());
 
         verify(ouService,
                never()).createOrganizationalUnit(eq("ou"),
                                                  eq(""));
-        verify(repositoryCopier,
-               times(2)).copy(eq(ou),
-                              anyString(),
-                              any(Path.class));
+        verify(service,
+               times(2)).importProject(eq(ou),
+                                       Mockito.<ImportProject>any());
 
         verify(newProjectEvent,
-               times(2)).fire(any(NewProjectEvent.class));
+               times(2)).fire(Mockito.<NewProjectEvent>any());
     }
 
     @Test
@@ -564,5 +568,12 @@ public class ExamplesServiceImplTest {
         when(ou1.getName()).thenReturn(".playground-1234");
         assertTrue(service.isOldPlayground(ou1));
     }
+
+    @Test
+    public void testExistSpace() {
+        java.nio.file.Path path = Paths.get("src/test/resources/niogit-test");
+        assertTrue(service.existSpace(".playground-hidden", path));
+        assertFalse(service.existSpace(".playground-1235", path));
+    }
 }
 
