@@ -42,7 +42,7 @@ import org.kie.workbench.common.screens.library.client.settings.util.sections.Me
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
 import org.kie.workbench.common.screens.projecteditor.model.ProjectScreenModel;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.promise.Promises;
 import org.uberfire.mocks.CallerMock;
@@ -50,12 +50,18 @@ import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.promise.SyncPromises;
 import org.uberfire.spaces.Space;
 
-import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class BranchManagementPresenterTest {
 
     @Mock
@@ -122,7 +128,7 @@ public class BranchManagementPresenterTest {
         permissionsByRole.put("CONTRIBUTOR", new RolePermissions("CONTRIBUTOR", true, false, true, true));
         doReturn(new BranchPermissions("myBranch", permissionsByRole)).when(libraryService).loadBranchPermissions("mySpace", "myProject", "myBranch");
 
-        doReturn(promises.resolve(Arrays.asList(new Branch("master", mock(Path.class)),
+        doReturn(promises.resolve(Arrays.asList(new Branch("main", mock(Path.class)),
                                                 new Branch("myBranch", mock(Path.class))))).when(projectController).getUpdatableBranches(any());
 
         presenter.setup(mock(ProjectScreenModel.class)).then(v -> {
