@@ -26,14 +26,14 @@ import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 public class UpdateElementPropertyCommand extends AbstractCanvasGraphCommand {
 
     private final Element element;
-    private final String propertyId;
+    private final String field;
     private final Object value;
 
     public UpdateElementPropertyCommand(final Element element,
-                                        final String propertyId,
+                                        final String field,
                                         final Object value) {
         this.element = element;
-        this.propertyId = propertyId;
+        this.field = field;
         this.value = value;
     }
 
@@ -41,12 +41,12 @@ public class UpdateElementPropertyCommand extends AbstractCanvasGraphCommand {
     @SuppressWarnings("unchecked")
     protected Command<GraphCommandExecutionContext, RuleViolation> newGraphCommand(final AbstractCanvasHandler context) {
         return (element instanceof Node ?
-            new UpdateElementPropertyValueCommand((Node) element,
-                                                  propertyId,
-                                                  value) :
-            new UpdateElementPropertyValueCommand(element.getUUID(),
-                                                  propertyId,
-                                                  value));
+                new UpdateElementPropertyValueCommand(element,
+                                                      field,
+                                                      value) :
+                new UpdateElementPropertyValueCommand(element.getUUID(),
+                                                      field,
+                                                      value));
     }
 
     @Override
@@ -58,11 +58,19 @@ public class UpdateElementPropertyCommand extends AbstractCanvasGraphCommand {
         return element;
     }
 
-    public String getPropertyId() {
-        return propertyId;
+    public String getField() {
+        return field;
     }
 
     public Object getValue() {
         return value;
     }
+
+    @Override
+    public String toString() {
+        return getClass().getSimpleName() +
+                " [element=" + toUUID(element) + "," +
+                "field=" + field + "," +
+                "value=" + value + "]";
+    }
 }
