@@ -24,19 +24,18 @@ import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotEquals;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class DeleteCanvasConnectorCommandTest extends AbstractCanvasCommandTest {
 
     private static final String EDGE_ID = "e1";
@@ -79,7 +78,39 @@ public class DeleteCanvasConnectorCommandTest extends AbstractCanvasCommandTest
     }
 
     @Test
-    public void testExecuteNullShape(){
+    @SuppressWarnings("unchecked")
+    public void testExecuteNullSourceNode() {
+        when(candidate.getSourceNode()).thenReturn(null);
+
+        final CommandResult<CanvasViolation> result = tested.execute(canvasHandler);
+        assertNotEquals(CommandResult.Type.ERROR,
+                        result.getType());
+        verify(canvasHandler,
+               times(1)).deregister(eq(candidate));
+        verify(canvasHandler,
+               never()).notifyCanvasElementUpdated(eq(source));
+        verify(canvasHandler,
+               times(1)).notifyCanvasElementUpdated(eq(target));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testExecuteNullTargetNode() {
+        when(candidate.getTargetNode()).thenReturn(null);
+
+        final CommandResult<CanvasViolation> result = tested.execute(canvasHandler);
+        assertNotEquals(CommandResult.Type.ERROR,
+                        result.getType());
+        verify(canvasHandler,
+               times(1)).deregister(eq(candidate));
+        verify(canvasHandler,
+               times(1)).notifyCanvasElementUpdated(eq(source));
+        verify(canvasHandler,
+               never()).notifyCanvasElementUpdated(eq(target));
+    }
+
+    @Test
+    public void testExecuteNullShape() {
         when(canvas.getShape(EDGE_ID)).thenReturn(null);
         assertFalse(CommandUtils.isError(tested.execute(canvasHandler)));
         verify(canvasHandler, never()).deregister(eq(candidate));
