@@ -17,6 +17,7 @@ package org.kie.workbench.common.stunner.core.graph.command.impl;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
 import org.jboss.errai.common.client.api.annotations.Portable;
+import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
@@ -25,13 +26,12 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecution
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
-import org.uberfire.commons.validation.PortablePreconditions;
 
 /**
  * A Command to delete an edge from a graph
  */
 @Portable
-public final class DeleteConnectorCommand extends AbstractGraphCompositeCommand {
+public class DeleteConnectorCommand extends AbstractGraphCompositeCommand {
 
     private final String edgeUUID;
     private transient Edge<? extends View, Node> edge;
@@ -54,16 +54,24 @@ public final class DeleteConnectorCommand extends AbstractGraphCompositeCommand
         final Node<View<?>, Edge> targetNode = edge.getTargetNode();
         final Node<View<?>, Edge> sourceNode = edge.getSourceNode();
         if (null != sourceNode) {
-            commands.add(new SetConnectionSourceNodeCommand(null,
-                                                            edge));
+            commands.add(getSetConnectionSourceCommand(edge));
         }
         if (null != targetNode) {
-            commands.add(new SetConnectionTargetNodeCommand(null,
-                                                            edge));
+            commands.add(getSetConnectionTargetCommand(edge));
         }
         return this;
     }
 
+    protected SetConnectionTargetNodeCommand getSetConnectionTargetCommand(final Edge<? extends ViewConnector, Node> edge) {
+        return new SetConnectionTargetNodeCommand(null,
+                                                  edge);
+    }
+
+    protected SetConnectionSourceNodeCommand getSetConnectionSourceCommand(final Edge<? extends ViewConnector, Node> edge) {
+        return new SetConnectionSourceNodeCommand(null,
+                                                  edge);
+    }
+
     @Override
     public CommandResult<RuleViolation> execute(final GraphCommandExecutionContext context) {
         final CommandResult<RuleViolation> result = super.execute(context);
