@@ -23,9 +23,10 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.svg.gen.model.impl.MultiPathDefinition;
 import org.kie.workbench.common.stunner.svg.gen.model.impl.StyleDefinitionImpl;
 import org.kie.workbench.common.stunner.svg.gen.model.impl.TransformDefinitionImpl;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 @RunWith(MockitoJUnitRunner.class)
 public class MultiPathDefinitionGeneratorTest {
@@ -40,6 +41,7 @@ public class MultiPathDefinitionGeneratorTest {
     private static final String STROKE_COLOR = "#654321";
     private static final double STROKE_ALPHA = 0.12d;
     private static final double STROKE_WIDTH = 5.6d;
+    private static final String STROKE_DASHARRAY = "5.00,5.00";
     private static final boolean LISTENING = false;
     private static final double VBOX_MIN_X = 12.6;
     private static final double VBOX_MIN_Y = 23.4;
@@ -49,12 +51,12 @@ public class MultiPathDefinitionGeneratorTest {
     private MultiPathDefinitionGenerator tested;
 
     @Before
-    public void setup() throws Exception {
+    public void setup() {
         tested = new MultiPathDefinitionGenerator();
     }
 
     @Test
-    public void testGetters() throws Exception {
+    public void testGetters() {
         assertEquals(MultiPathDefinition.class,
                      tested.getDefinitionType());
         assertEquals("MultiPath",
@@ -75,13 +77,14 @@ public class MultiPathDefinitionGeneratorTest {
                                               .setStrokeColor(STROKE_COLOR)
                                               .setStrokeAlpha(STROKE_ALPHA)
                                               .setStrokeWidth(STROKE_WIDTH)
+                                              .setStrokeDashArray(STROKE_DASHARRAY)
                                               .build());
         definition.setTransformDefinition(new TransformDefinitionImpl(VBOX_WIDTH,
                                                                       VBOX_HEIGHT,
                                                                       VBOX_MIN_X,
                                                                       VBOX_MIN_Y));
         final String generated = tested.generate(definition).toString();
-        assertTrue(generated.contains("new " + MultiPath.class.getName() + "(" + GeneratorAssertions.formatString(PATH) + ")"));
+        assertTrue(generated.contains("new " + MultiPath.class.getName() + "(" + SVGViewFactoryGenerator.FIELD_STATICS + ID.toUpperCase() + ")"));
         GeneratorAssertions.assertDraggable(generated);
         GeneratorAssertions.assertID(generated,
                                      ID);
@@ -104,6 +107,8 @@ public class MultiPathDefinitionGeneratorTest {
                                               STROKE_ALPHA);
         GeneratorAssertions.assertStrokeWidth(generated,
                                               STROKE_WIDTH);
+        GeneratorAssertions.assertStrokeDashArray(generated,
+                                                  STROKE_DASHARRAY);
         GeneratorAssertions.assertListening(generated,
                                             LISTENING);
     }
