@@ -33,11 +33,11 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
@@ -49,7 +49,7 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 @Bindable
 @CanContain(roles = {"cm_activity", "cm_stage", "IntermediateEventsMorph", "GatewaysMorph", "EndEventsMorph", "text_annotation", "connector"})
 @CanDock(roles = {"IntermediateEventOnSubprocessBoundary"})
-@Definition(graphFactory = NodeFactory.class)
+@Definition
 @Morph(base = BaseSubprocess.class)
 @FormDefinition(
         startElement = "general",
@@ -59,12 +59,12 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 public class AdHocSubprocess
         extends BaseAdHocSubprocess<ProcessData, AdHocSubprocessTaskExecutionSet> {
 
-    @PropertySet
+    @Property
     @FormField(afterElement = "general")
     @Valid
     protected AdHocSubprocessTaskExecutionSet executionSet;
 
-    @PropertySet
+    @Property
     @FormField(afterElement = "executionSet")
     @Valid
     private ProcessData processData;
@@ -79,6 +79,7 @@ public class AdHocSubprocess
              new FontSet(),
              new RectangleDimensionsSet(),
              new SimulationSet(),
+             new AdvancedData(),
              new AdHocSubprocessTaskExecutionSet(),
              new ProcessData());
     }
@@ -88,13 +89,15 @@ public class AdHocSubprocess
                            final @MapsTo("fontSet") FontSet fontSet,
                            final @MapsTo("dimensionsSet") RectangleDimensionsSet dimensionsSet,
                            final @MapsTo("simulationSet") SimulationSet simulationSet,
+                           final @MapsTo("advancedData") AdvancedData advancedData,
                            final @MapsTo("executionSet") AdHocSubprocessTaskExecutionSet executionSet,
                            final @MapsTo("processData") ProcessData processData) {
         super(general,
               backgroundSet,
               fontSet,
               dimensionsSet,
-              simulationSet);
+              simulationSet,
+              advancedData);
         this.executionSet = executionSet;
         this.processData = processData;
     }
