@@ -17,9 +17,9 @@
 package org.kie.workbench.common.stunner.bpmn.definition;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
@@ -27,43 +27,41 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Circ
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Radius;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
+
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
 
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, builder = EndNoneEvent.EndNoneEventBuilder.class)
+@Definition
 @Morph(base = BaseEndEvent.class)
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class EndNoneEvent extends BaseEndEvent {
 
-    @NonPortable
-    public static class EndNoneEventBuilder implements Builder<EndNoneEvent> {
-
-        @Override
-        public EndNoneEvent build() {
-            return new EndNoneEvent(new BPMNGeneralSet(""),
-                                    new BackgroundSet(),
-                                    new FontSet(),
-                                    new CircleDimensionSet(new Radius()));
-        }
-    }
-
     public EndNoneEvent() {
+        this(new BPMNGeneralSet(""),
+             new BackgroundSet(),
+             new FontSet(),
+             new CircleDimensionSet(new Radius()),
+             new AdvancedData());
     }
 
     public EndNoneEvent(final @MapsTo("general") BPMNGeneralSet general,
                         final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
                         final @MapsTo("fontSet") FontSet fontSet,
-                        final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet) {
+                        final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet,
+                        final @MapsTo("advancedData") AdvancedData advancedData) {
         super(general,
               backgroundSet,
               fontSet,
-              dimensionsSet);
+              dimensionsSet,
+              advancedData);
     }
 }
