@@ -27,12 +27,10 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNPropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @Portable
 @Bindable
-@PropertySet
 @FormDefinition(
         startElement = "script"
 )
@@ -106,8 +104,8 @@ public class ScriptTaskExecutionSet implements BPMNPropertySet {
         if (o instanceof ScriptTaskExecutionSet) {
             ScriptTaskExecutionSet other = (ScriptTaskExecutionSet) o;
             return Objects.equals(script, other.script) &&
-                   Objects.equals(isAsync, other.isAsync) &&
-                   Objects.equals(adHocAutostart, other.adHocAutostart);
+                    Objects.equals(isAsync, other.isAsync) &&
+                    Objects.equals(adHocAutostart, other.adHocAutostart);
         }
         return false;
     }
