@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.bpmn.backend.converters.custompropertie
 
 import java.util.Objects;
 
+import com.google.common.base.Strings;
 import org.eclipse.bpmn2.ItemDefinition;
 import org.eclipse.bpmn2.Property;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.Ids;
@@ -30,13 +31,13 @@ public class VariableDeclaration {
     private final Property typedIdentifier;
     private String identifier;
     private String type;
-    private String kpi;
+    private String tags;
 
     public VariableDeclaration(String identifier, String type) {
         this(identifier, type, "");
     }
 
-    public VariableDeclaration(String identifier, String type, String kpi) {
+    public VariableDeclaration(String identifier, String type, String tags) {
         this.setIdentifier(identifier);
         this.type = type;
 
@@ -48,28 +49,29 @@ public class VariableDeclaration {
         this.typedIdentifier.setId(Ids.typedIdentifier("GLOBAL", this.getIdentifier()));
         this.typedIdentifier.setName(identifier);
         this.typedIdentifier.setItemSubjectRef(typeDeclaration);
-        this.kpi = kpi;
+        this.tags = tags;
     }
 
     public static VariableDeclaration fromString(String encoded) {
         String[] split = encoded.split(":");
         String identifier = split[0];
         String type = (split.length == 2 || split.length == 3) ? split[1] : "";
-        if (identifier.isEmpty()) {
-            throw new IllegalArgumentException("Variable identifier cannot be empty. Given: '" + encoded + "'");
-        }
-        String kpi = "";
+        String tags = "";
 
         if (split.length == 3) {
-            kpi = split[2];
+            tags = split[2];
         }
 
-        return new VariableDeclaration(identifier, type, kpi);
+        return new VariableDeclaration(identifier, type, tags);
     }
 
-    public String getKpi() { return kpi; }
+    public String getTags() {
+        return tags;
+    }
 
-    public void setKpi(String kpi) { this.kpi = kpi; }
+    public void setTags(String tags) {
+        this.tags = tags;
+    }
 
     public String getIdentifier() {
         return identifier;
@@ -98,14 +100,14 @@ public class VariableDeclaration {
 
     @Override
     public String toString() {
-        String kpiString = "";
-        if (kpi != null && !kpi.isEmpty()) {
-            kpiString = ":" + kpi;
+        String tagsString = "";
+        if (!Strings.isNullOrEmpty(tags)) {
+            tagsString = ":" + tags;
         }
         if (type == null || type.isEmpty()) {
-            return typedIdentifier.getName() + kpiString;
+            return typedIdentifier.getName() + tagsString;
         } else {
-            return typedIdentifier.getName() + ":" + type + kpiString;
+            return typedIdentifier.getName() + ":" + type + tagsString;
         }
     }
 
@@ -120,12 +122,12 @@ public class VariableDeclaration {
         VariableDeclaration that = (VariableDeclaration) o;
         return Objects.equals(identifier, that.identifier) &&
                 Objects.equals(type, that.type) &&
-                Objects.equals(kpi, that.kpi);
+                Objects.equals(tags, that.tags);
     }
 
     @Override
     public int hashCode() {
-        return Objects.hash(identifier, type, kpi);
+        return Objects.hash(identifier, type, tags);
     }
 }
 
