@@ -78,7 +78,7 @@ public class SubProcessConverter extends ProcessConverterDelegate {
         return processRootResult;
     }
 
-    private SubProcessPropertyWriter convertMultipleInstanceSubprocessNode(Node<View<MultipleInstanceSubprocess>, ?> n) {
+    protected SubProcessPropertyWriter convertMultipleInstanceSubprocessNode(Node<View<MultipleInstanceSubprocess>, ?> n) {
         SubProcess process = bpmn2.createSubProcess();
         process.setId(n.getUUID());
 
@@ -103,8 +103,10 @@ public class SubProcessConverter extends ProcessConverterDelegate {
         p.setOnEntryAction(executionSet.getOnEntryAction());
         p.setOnExitAction(executionSet.getOnExitAction());
         p.setAsync(executionSet.getIsAsync().getValue());
+        p.setSlaDueDate(executionSet.getSlaDueDate());
 
         p.setSimulationSet(definition.getSimulationSet());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAbsoluteBounds(n);
 
@@ -132,8 +134,11 @@ public class SubProcessConverter extends ProcessConverterDelegate {
         p.setAdHocOrdering(executionSet.getAdHocOrdering());
         p.setOnEntryAction(executionSet.getOnEntryAction());
         p.setOnExitAction(executionSet.getOnExitAction());
+        p.setAsync(executionSet.getIsAsync().getValue());
+        p.setSlaDueDate(executionSet.getSlaDueDate());
 
         p.setSimulationSet(definition.getSimulationSet());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAbsoluteBounds(n);
 
@@ -142,7 +147,7 @@ public class SubProcessConverter extends ProcessConverterDelegate {
         return p;
     }
 
-    private SubProcessPropertyWriter convertEventSubprocessNode(Node<View<EventSubprocess>, ?> n) {
+    protected SubProcessPropertyWriter convertEventSubprocessNode(Node<View<EventSubprocess>, ?> n) {
         SubProcess process = bpmn2.createSubProcess();
         process.setId(n.getUUID());
 
@@ -160,15 +165,17 @@ public class SubProcessConverter extends ProcessConverterDelegate {
 
         EventSubprocessExecutionSet executionSet = definition.getExecutionSet();
         p.setAsync(executionSet.getIsAsync().getValue());
+        p.setSlaDueDate(executionSet.getSlaDueDate());
 
         p.setSimulationSet(definition.getSimulationSet());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAbsoluteBounds(n);
 
         return p;
     }
 
-    private SubProcessPropertyWriter convertEmbeddedSubprocessNode(Node<View<EmbeddedSubprocess>, ?> n) {
+    protected SubProcessPropertyWriter convertEmbeddedSubprocessNode(Node<View<EmbeddedSubprocess>, ?> n) {
         SubProcess process = bpmn2.createSubProcess();
         process.setId(n.getUUID());
 
@@ -185,11 +192,13 @@ public class SubProcessConverter extends ProcessConverterDelegate {
         p.setOnEntryAction(executionSet.getOnEntryAction());
         p.setOnExitAction(executionSet.getOnExitAction());
         p.setAsync(executionSet.getIsAsync().getValue());
+        p.setSlaDueDate(executionSet.getSlaDueDate());
 
         ProcessData processData = definition.getProcessData();
         p.setProcessVariables(processData.getProcessVariables());
 
         p.setSimulationSet(definition.getSimulationSet());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
         p.setAbsoluteBounds(n);
         return p;
     }
