@@ -17,7 +17,6 @@
 package org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties;
 
 import java.util.Objects;
-import java.util.Optional;
 
 import org.eclipse.bpmn2.AdHocSubProcess;
 import org.eclipse.bpmn2.Association;
@@ -25,6 +24,7 @@ import org.eclipse.bpmn2.BoundaryEvent;
 import org.eclipse.bpmn2.BusinessRuleTask;
 import org.eclipse.bpmn2.CallActivity;
 import org.eclipse.bpmn2.CatchEvent;
+import org.eclipse.bpmn2.DataObjectReference;
 import org.eclipse.bpmn2.Definitions;
 import org.eclipse.bpmn2.FlowElement;
 import org.eclipse.bpmn2.Gateway;
@@ -41,6 +41,7 @@ import org.eclipse.bpmn2.UserTask;
 import org.eclipse.bpmn2.di.BPMNDiagram;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.CustomAttribute;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.DefinitionResolver;
+import org.kie.workbench.common.stunner.bpmn.backend.workitem.WorkItemDefinitionParser;
 
 public class PropertyReaderFactory {
 
@@ -96,14 +97,18 @@ public class PropertyReaderFactory {
         return new BusinessRuleTaskPropertyReader(el, diagram, definitionResolver);
     }
 
-    public Optional<ServiceTaskPropertyReader> ofCustom(Task el) {
+    public ServiceTaskPropertyReader ofCustom(Task el) {
         String serviceTaskName = CustomAttribute.serviceTaskName.of(el).get();
         return definitionResolver
                 .getWorkItemDefinitions()
                 .stream()
                 .filter(wid -> Objects.equals(wid.getName(), serviceTaskName))
                 .findFirst()
-                .map(def -> new ServiceTaskPropertyReader(el, def, diagram, definitionResolver));
+                .map(def -> new ServiceTaskPropertyReader(el, def, diagram, definitionResolver))
+                .orElseGet(() -> new ServiceTaskPropertyReader(el,
+                                                               WorkItemDefinitionParser.emptyWid().setName(serviceTaskName),
+                                                               diagram,
+                                                               definitionResolver));
     }
 
     public CallActivityPropertyReader of(CallActivity el) {
@@ -145,4 +150,8 @@ public class PropertyReaderFactory {
     public DefinitionsPropertyReader of(Definitions el) {
         return new DefinitionsPropertyReader(el, diagram, definitionResolver.getShape(el.getId()), definitionResolver.getResolutionFactor());
     }
+
+    public DataObjectPropertyReader of(DataObjectReference el) {
+        return new DataObjectPropertyReader(el, diagram, definitionResolver.getShape(el.getId()), definitionResolver.getResolutionFactor());
+    }
 }
