@@ -62,7 +62,7 @@ import org.kie.workbench.common.stunner.core.marshaller.MarshallingMessage;
 import org.kie.workbench.common.stunner.core.marshaller.MarshallingMessageKeys;
 import org.kie.workbench.common.stunner.core.validation.Violation;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -71,7 +71,7 @@ import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ProcessConverterDelegateTest {
 
     @Mock
@@ -182,6 +182,24 @@ public class ProcessConverterDelegateTest {
         assertTrue(messages.stream().map(MarshallingMessage::getViolationType).allMatch(Violation.Type.WARNING::equals));
     }
 
+    @Test
+    public void testConvertIgnoredFlowElements() {
+        List<LaneSet> laneSets = Collections.emptyList();
+        //adding 2 supported and 2 unsupported elements
+        List<FlowElement> flowElements = Arrays.asList(mockTask("1"),
+                                                       mockTask("2"),
+                                                       mockSequenceFlow("3", null, null),
+                                                       mockUnsupportedDataObject("4"));
+
+        Result<Map<String, BpmnNode>> result = converterDelegate.convertChildNodes(parentNode, flowElements, laneSets);
+        Map<String, BpmnNode> values = result.value();
+        List<MarshallingMessage> messages = result.messages();
+        //check one message per unsupported element
+        assertEquals(2, values.size());
+        assertEquals(1, messages.size());
+        assertTrue(messages.stream().map(MarshallingMessage::getViolationType).allMatch(Violation.Type.WARNING::equals));
+    }
+
     @Test
     public void testConvertLanes() {
         Task task0_1 = mockTask("TASK0_1");
