@@ -25,7 +25,7 @@ import org.eclipse.bpmn2.EventDefinition;
 import org.eclipse.bpmn2.SignalEventDefinition;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.mockito.Mockito.when;
 
@@ -47,6 +47,13 @@ public class CatchEventPropertyReaderTest extends BaseEventPropertyReaderTest {
         when(catchEvent.getEventDefinitionRefs()).thenReturn(Collections.EMPTY_LIST);
     }
 
+    @Override
+    protected void setLinkEventDefinitionOnCurrentMock(EventDefinition eventDefinition) {
+        List<EventDefinition> eventDefinitions = Collections.singletonList(eventDefinition);
+        when(catchEvent.getEventDefinitions()).thenReturn(eventDefinitions);
+        when(catchEvent.getEventDefinitionRefs()).thenReturn(Collections.EMPTY_LIST);
+    }
+
     @Override
     protected Event getCurrentEventMock() {
         return catchEvent;
