@@ -38,6 +38,7 @@ import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.when;
 
@@ -156,6 +157,24 @@ public class WorkItemDefinitionParserTest {
         assertEquals("||", workItemDefinition.getResults());
     }
 
+    @Test
+    public void testEmptyWorkItemDefinition() {
+        WorkItemDefinition wid = WorkItemDefinitionParser.emptyWid();
+
+        assertNotNull(wid.getIconDefinition());
+        assertTrue(wid.getIconDefinition().getUri().isEmpty());
+        assertTrue(wid.getUri().isEmpty());
+        assertTrue(wid.getName().isEmpty());
+        assertTrue(wid.getCategory().isEmpty());
+        assertTrue(wid.getDescription().isEmpty());
+        assertTrue(wid.getDocumentation().isEmpty());
+        assertTrue(wid.getDisplayName().isEmpty());
+        assertTrue(wid.getResults().isEmpty());
+        assertTrue(wid.getDefaultHandler().isEmpty());
+        assertNotNull(wid.getDependencies());
+        assertTrue(wid.getParameters().isEmpty());
+    }
+
     public static String loadStream(String path) throws IOException {
         final StringWriter writer = new StringWriter();
         IOUtils.copy(Thread.currentThread()
