@@ -19,8 +19,8 @@ package org.kie.workbench.common.widgets.configresource.client.widget.bound;
 import java.util.List;
 
 import com.google.gwt.user.client.ui.Widget;
-import org.drools.workbench.models.datamodel.imports.Import;
-import org.drools.workbench.models.datamodel.imports.Imports;
+import org.kie.soup.project.datamodel.imports.Import;
+import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.uberfire.client.mvp.UberView;
 
@@ -46,4 +46,10 @@ public interface ImportsWidgetView
                     final List<Import> externalFactTypes,
                     final List<Import> modelFactTypes,
                     final boolean isReadOnly);
+
+    /**
+     * Method refresh the set of used columns according to actual imports.
+     * We do not render 'Remove' column if just non removable imports are present.
+     */
+    void updateRenderedColumns();
 }
